@@ -2,7 +2,7 @@ package CallBackery::Database;
 
 # $Id: Database.pm 542 2013-12-12 16:36:34Z oetiker $
 
-use Mojo::Base -base;
+use Mojo::Base -base,-signatures;
 
 use Data::Dumper;
 use Carp qw(croak);
@@ -77,7 +77,9 @@ has sql => sub {
         ->from_data(__PACKAGE__,'dbsetup.sql')
         ->migrate;
 
-    $sql->db->dbh->do('PRAGMA foreign_keys = ON');
+    $sql->on(connection => sub ($sql, $dbh) {
+      $dbh->do('PRAGMA foreign_keys = ON;');
+    });
 
     return $sql;
 };
