@@ -255,14 +255,6 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                             s.set[key] = this.xtr(s.set[key]);
                         }
                     }, this);
-                    // set readOnly of _cfg element in case it changed in reconfigure
-                    if (s.set.readOnly != undefined) {
-                        this._cfg.form.forEach(function(el) {
-                            if (el.key == [s.key]) {
-                                el.set.readOnly = s.set.readOnly;
-                            }
-                        }, this);
-                    }
                     var ctrl = this._form.getControl(s.key);
                     ctrl.set(s.set);
                 }
